pub struct WebPushAlerts {
pub follow: bool,
pub favourite: bool,
pub reblog: bool,
pub mention: bool,
pub poll: bool,
pub status: bool,
}Expand description
Represents the alerts that can be delivered via Web Push.
Fields
follow: boolWhether to notify on new followers.
favourite: boolWhether to notify on new favourites.
reblog: boolWhether to notify on new reblogs.
mention: boolWhether to notify on new mentions.
poll: boolWhether to notify on new poll results.
status: boolWhether to notify on new statuses from followed accounts.