pub struct WebPushSubscription {
pub id: u64,
pub endpoint: String,
pub server_key: String,
pub alerts: WebPushAlerts,
}Expand description
Represents a subscription to the Web Push API.
Fields
id: u64The ID of the Web Push subscription in the database.
endpoint: StringThe endpoint of the Web Push subscription.
server_key: StringThe server key used for the Web Push subscription.
alerts: WebPushAlertsWhich alerts should be delivered to the push endpoint.